#!/bin/perl
#
# send_sms_AlarmManagerPro.pl - nagios notification plugin
#
# Copyright (C) 2012 B1 Systems GmbH <info@b1-systems.de>,
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
#
#
## purpose: connect to Kentix AlarmManagerPro and send a SMS.
## author: Christian Schneemann <schneemann@b1-systems.de>, 2012.


use strict;
use warnings;

use URI::Escape;
use LWP::UserAgent;
use Getopt::Long;
use File::Basename;

my $VERSION = "1.0.0";


my $sendtext;
my $smstext;
my $user;
my $password;
my $alarmmanagerpro;
my $recipient;
my $help;
my $version;

my $timeout = 15;


my $basename = basename($0);
sub usage() {
    print "Usage: $basename --alarmmanagerpro <host> --user <user>\n";
    print "          --password <password> --recipient <phonenumber> --smstext [-t <timeout>]\n";
    print "\n";
    print "--alarmmanagerpro, -a  Hostname/IP of AlarmManagerPro\n";
    print "--user, -p             name of Kentix AlarmManagerPro user allowd to send SMS\n";
    print "--password, -p         password for AlarmManagerPro user allowd to send SMS\n";
    print "--recipient, -r        recipient\n";
    print "--smstext, -s          SMS text, will be cut of after 160 chars\n";
    print "--timeout, -t          set timeout in seconds (default: 15)\n";
    print "--help, --usage, -h    print this text\n";
    print "--version, -v          print version\n"; 
}

my $options = GetOptions("alarmmanagerpro|a=s" => \$alarmmanagerpro,
                         "user|u=s"            => \$user,
                         "password|p=s"        => \$password,
                         "smstext|s=s"         => \$smstext,
                         "timeout|t=i"         => \$timeout,
                         "recipient|r=s"       => \$recipient,
                         "help|usage|h"        => \$help,
                         "version|v"           => \$version,
                        ) or die($!);

if (defined($help)) {
    usage();
    exit 0;
}
if (defined($version)) {
    print "Version: $VERSION\n";
    exit 0;
}


my @error;

if ( !defined($alarmmanagerpro) ) {
    push @error, "--alarmanagerpro, -a <-- Parameter missing!\n";
}

if ( !defined($user) ) {
    push @error, "--user, -u <-- Parameter missing!\n";
}

if ( !defined($password) ) {
    push @error, "--password, -p <-- Parameter missing!\n";
}

if ( !defined($smstext) ) {
    push @error, "--smstext, -s <-- Parameter missing!\n";
}

if ( !defined($recipient) ) {
    push @error, "--recipient, -r <-- Parameter missing!\n";
}

if ( @error ) {
    print @error;
    exit 2;
}



# test if $np->opts->text is longer than 160 chars, if yes cut it
if (length($smstext) > 160) {
    $sendtext = substring($smstext, 0, 159);
} else {
    $sendtext = $smstext;
}

my $req = "http://$alarmmanagerpro/sendmsg";
$req   .= "?user=" . uri_escape($user);
$req   .= "&password=" . uri_escape($password);
$req   .= "&to=" . uri_escape($recipient);
$req   .= "&text=" . uri_escape($sendtext);

my $res = "";
my $ua = LWP::UserAgent->new();
$ua->timeout($timeout);
my $response = $ua->request(HTTP::Request->new('GET', $req));
 
if ( $response->code != "200" ) { 
    print "error: ", $response->content(), "\n";
    exit 2;
} else {
    print "OK: ", $response->content(), "\n";    
    exit 0;
} 

